COMPACT_IMAGE_RESIZE_PERCENT = 70
THUMBNAIL_IMAGE_RESIZE_PERCENT = 50
MINIMUM_IMAGE_SIZE = 1000000  # In Kilobytes
MINIMUM_HWIDTH = 1920
MINIMUM_HHEIGHT = 1080
MINIMUM_VWIDTH = 1080
MINIMUM_VHEIGHT = 1920
