# Generated by Django 5.0.6 on 2024-06-26 11:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simple_media_manager', '0003_alter_image_options_rename_image_image_original'),
    ]

    operations = [
        migrations.AlterField(
            model_name='image',
            name='compact',
            field=models.ImageField(null=True, upload_to='media/images/compacts', verbose_name='compact size'),
        ),
        migrations.AlterField(
            model_name='image',
            name='original',
            field=models.ImageField(null=True, upload_to='media/images/originals', verbose_name='original size'),
        ),
        migrations.AlterField(
            model_name='image',
            name='thumbnail',
            field=models.ImageField(null=True, upload_to='media/images/thumbnails', verbose_name='thumbnail size'),
        ),
    ]
