# Generated by Django 5.0.6 on 2024-06-05 13:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simple_media_manager', '0002_image_compact_image_thumbnail_alter_image_image'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='image',
            options={'ordering': ('-created_at',)},
        ),
        migrations.RenameField(
            model_name='image',
            old_name='image',
            new_name='original',
        ),
    ]
